"""DB Factory"""
from typing import Dict, Union

import pydb


def db_factory(db_info: Union[Dict[str, int], Dict[str, str]], db_type: str):
    """
    Returns a database object based on the database type.

    Parameters
    ----------
    db_info: dict
        Dictionary containing database connection information
    db_type: str
        Database type (mysql, oracle, snowflake)

    Returns
    -------
        Database object
    """
    db_type = db_type.strip().lower()
    if db_type == "mysql":
        return pydb.db.MysqlDB(db_info)
    if db_type == "snowflake":
        return pydb.db.SnowflakeWrapper(db_info)
    if db_type in ("oracle", "prepdb", "bengal", "livdb", "slivdb"):
        return pydb.db.OracleWrapper(db_info)
    print("ERROR", db_type, "not valid")
    print("Valid types: [ mysql | oracle | snowflake ]")
    raise ValueError("Invalid database type")
